@@ -3,18 +3,19 @@ from typing import Any, Optional
 from sanic.exceptions import SanicException
 
 from sanic_api.enum import EnumBase, RespCodeEnum
+from sanic_api.utils import get_current_request
 
 
 class ServerException(SanicException):
     def __init__(
         self,
         message: Optional[str] = None,
-        server_code: Optional[EnumBase] = None,
         status_code: Optional[int] = None,
+        server_code: Optional[EnumBase] = None,
         quiet: Optional[bool] = None,
         context: Any = None,
         extra=None,
-    ) -> None:
+    ):
         super().__init__(
             message=message,
             status_code=status_code,
@@ -25,6 +26,9 @@ class ServerException(SanicException):
         self.server_code = server_code or RespCodeEnum.FAILED
         self.message = message or self.server_code.desc
         self.status_code = status_code or 200
+        req = get_current_request()
+        if req:
+            req.ctx.exception = self
 
 
 class ValidationInitError(ServerException):
